@@ -107,8 +107,8 @@ class DVBManagerClient(gobject.GObject):
     def get_recorder(self, group_id):
         return self.manager.GetRecorder(group_id)
         
-    def add_device_to_new_group (self, adapter, frontend, channels_file, recordings_dir):
-        return self.manager.AddDeviceToNewGroup(adapter, frontend, channels_file, recordings_dir)
+    def add_device_to_new_group (self, adapter, frontend, channels_file, recordings_dir, name):
+        return self.manager.AddDeviceToNewGroup(adapter, frontend, channels_file, recordings_dir, name)
         
     def add_device_to_existing_group (self, adapter, frontend, group_id):
         return self.manager.AddDeviceToExistingGroup(adapter, frontend, group_id)
@@ -119,6 +119,9 @@ class DVBManagerClient(gobject.GObject):
     def get_device_group_members(self, group_id):
         return self.manager.GetDeviceGroupMembers(group_id)
         
+    def get_device_group_name(self, group_id):
+        return self.manager.GetDeviceGroupName(group_id)
+        
     def get_type_of_device_group(self, group_id):
         return self.manager.GetTypeOfDeviceGroup(group_id)
         
@@ -138,8 +141,8 @@ class DVBScannerClient(gobject.GObject):
 
     __gsignals__ = {
         "finished":          (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
-        "frequency-scanned": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int]),
-        "channel-added":     (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int, str, str, str]), 
+        "frequency-scanned": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int]),
+        "channel-added":     (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int, str, str, str, bool]),
         "destroyed":         (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
     }
 
@@ -168,18 +171,15 @@ class DVBScannerClient(gobject.GObject):
         
     def write_channels_to_file(self, channelfile):
         self.scanner.WriteChannelsToFile(channelfile)
-        
-    def get_queue_size(self):
-        return self.scanner.GetQueueSize()
-        
+    
     def on_finished(self):
         self.emit("finished")
         
-    def on_frequency_scanned(self, freq):
-        self.emit("frequency-scanned", freq)
+    def on_frequency_scanned(self, freq, freq_left):
+        self.emit("frequency-scanned", freq, freq_left)
         
-    def on_channel_added(self, freq, sid, name, network, channeltype):
-        self.emit("channel-added", freq, sid, name, network, channeltype)
+    def on_channel_added(self, freq, sid, name, network, channeltype, scrambled):
+        self.emit("channel-added", freq, sid, name, network, channeltype, scrambled)
         
     def on_destroyed(self):
         self.emit("destroyed")
@@ -436,5 +436,7 @@ if __name__ == '__main__':
         print "Start", recstore.get_start_time(rid)
         print recstore.get_start_timestamp(rid)
         print "Length", recstore.get_length(rid)    
+        print "Name", recstore.get_name (rid)
+        print "Desc", recstore.get_description(rid)
     
     loop.run()
