@@ -6,8 +6,8 @@
 #include <glib-object.h>
 #include <gee/iterable.h>
 #include <gee/hashmap.h>
-#include <gee/iterator.h>
 #include <gio/gio.h>
+#include <gee/iterator.h>
 #include <stdlib.h>
 #include <string.h>
 #include "src/IDBusChannelList.h"
@@ -39,14 +39,14 @@ struct _DVBChannelListClass {
 };
 
 
+DVBChannelList* dvb_channel_list_construct (GType object_type, GFile* channels);
+DVBChannelList* dvb_channel_list_new (GFile* channels);
 DVBChannel* dvb_channel_list_get (DVBChannelList* self, guint sid);
 void dvb_channel_list_add (DVBChannelList* self, DVBChannel* channel);
 void dvb_channel_list_remove (DVBChannelList* self, guint sid);
 gboolean dvb_channel_list_contains (DVBChannelList* self, guint sid);
 void dvb_channel_list_clear (DVBChannelList* self);
 DVBChannelList* dvb_channel_list_restore_from_file (GFile* channelsfile, DVBAdapterType type, GError** error);
-DVBChannelList* dvb_channel_list_construct (GType object_type);
-DVBChannelList* dvb_channel_list_new (void);
 GFile* dvb_channel_list_get_channels_file (DVBChannelList* self);
 gint dvb_channel_list_get_size (DVBChannelList* self);
 guint dvb_channel_list_get_group_id (DVBChannelList* self);
