@@ -27,7 +27,7 @@ enum  {
 };
 #define DVB_DEVICE_PRIME 31
 static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type);
-static const char* dvb_device_getAdapterName (guint adapter, gboolean get_name);
+static char* dvb_device_getAdapterName (guint adapter, gboolean get_name);
 static void dvb_device_set_Adapter (DVBDevice* self, guint value);
 static void dvb_device_set_Frontend (DVBDevice* self, guint value);
 static void dvb_device_set_Type (DVBDevice* self, DVBAdapterType value);
@@ -52,6 +52,7 @@ GType dvb_adapter_type_get_type (void) {
 DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint frontend, gboolean get_type_and_name) {
 	GParameter * __params;
 	GParameter * __params_it;
+	char* _tmp0;
 	DVBDevice * self;
 	__params = g_new0 (GParameter, 4);
 	__params_it = __params;
@@ -67,10 +68,12 @@ DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint fronten
 	g_value_init (&__params_it->value, DVB_TYPE_ADAPTER_TYPE);
 	g_value_set_enum (&__params_it->value, dvb_device_getAdapterType (adapter, get_type_and_name));
 	__params_it++;
+	_tmp0 = NULL;
 	__params_it->name = "Name";
 	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, dvb_device_getAdapterName (adapter, get_type_and_name));
+	g_value_set_string (&__params_it->value, _tmp0 = dvb_device_getAdapterName (adapter, get_type_and_name));
 	__params_it++;
+	_tmp0 = (g_free (_tmp0), NULL);
 	self = g_object_newv (object_type, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -135,197 +138,222 @@ guint dvb_device_hash_without_device (guint adapter, guint frontend) {
 gboolean dvb_device_is_busy (DVBDevice* self) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp0;
+	GstElement* _tmp1;
 	GstBus* bus;
 	gboolean busy_val;
-	gboolean _tmp6;
+	gboolean _tmp7;
 	g_return_val_if_fail (self != NULL, FALSE);
 	dvbsrc = gst_element_factory_make ("dvbsrc", "text_dvbsrc");
+	if (dvbsrc == NULL) {
+		gboolean _tmp0;
+		g_critical ("Device.vala:60: Could not create dvbsrc element");
+		return (_tmp0 = TRUE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp0);
+	}
 	g_object_set ((GObject*) dvbsrc, "adapter", self->priv->_Adapter, NULL);
 	g_object_set ((GObject*) dvbsrc, "frontend", self->priv->_Frontend, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
-	_tmp0 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp0 = dvbsrc, (_tmp0 == NULL) ? NULL : gst_object_ref (_tmp0)));
+	_tmp1 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	busy_val = FALSE;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
-		gboolean _tmp1;
+		gboolean _tmp2;
 		msg = gst_bus_pop (bus);
-		_tmp1 = FALSE;
+		_tmp2 = FALSE;
 		if (msg->type == GST_MESSAGE_ERROR) {
-			_tmp1 = msg->src == GST_OBJECT (dvbsrc);
+			_tmp2 = msg->src == GST_OBJECT (dvbsrc);
 		} else {
-			_tmp1 = FALSE;
+			_tmp2 = FALSE;
 		}
-		if (_tmp1) {
+		if (_tmp2) {
 			GError* gerror;
 			char* debug_text;
+			char* _tmp6;
 			char* _tmp5;
-			char* _tmp4;
+			GError* _tmp4;
 			GError* _tmp3;
-			GError* _tmp2;
 			gerror = NULL;
 			debug_text = NULL;
+			_tmp6 = NULL;
 			_tmp5 = NULL;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			_tmp2 = NULL;
-			(gst_message_parse_error (msg, &_tmp2, &_tmp4), gerror = (_tmp3 = _tmp2, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp3));
-			debug_text = (_tmp5 = _tmp4, debug_text = (g_free (debug_text), NULL), _tmp5);
-			g_debug (gerror->message);
-			g_debug (debug_text);
+			(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
+			debug_text = (_tmp6 = _tmp5, debug_text = (g_free (debug_text), NULL), _tmp6);
+			g_debug ("Device.vala:82: Error tuning: %s; %s", gerror->message, debug_text);
 			busy_val = TRUE;
 			(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 			debug_text = (g_free (debug_text), NULL);
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
-	return (_tmp6 = busy_val, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp6);
+	return (_tmp7 = busy_val, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp7);
 }
 
 
 static DVBAdapterType dvb_device_getAdapterType (guint adapter, gboolean get_type) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp1;
+	GstElement* _tmp2;
 	GstBus* bus;
-	const char* adapter_type;
+	char* adapter_type;
 	if (!get_type) {
 		return DVB_ADAPTER_TYPE_UNKNOWN;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
+	if (dvbsrc == NULL) {
+		DVBAdapterType _tmp1;
+		g_critical ("Device.vala:98: Could not create dvbsrc element");
+		return (_tmp1 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+	}
 	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
-	_tmp1 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	adapter_type = NULL;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
-		gboolean _tmp2;
+		gboolean _tmp3;
 		msg = gst_bus_pop (bus);
-		_tmp2 = FALSE;
+		_tmp3 = FALSE;
 		if (msg->type == GST_MESSAGE_ELEMENT) {
-			_tmp2 = msg->src == GST_OBJECT (dvbsrc);
+			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
 		} else {
-			_tmp2 = FALSE;
+			_tmp3 = FALSE;
 		}
-		if (_tmp2) {
+		if (_tmp3) {
 			const GstStructure* structure;
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				adapter_type = gst_structure_get_string (structure, "type");
+				char* _tmp4;
+				_tmp4 = NULL;
+				adapter_type = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "type")), adapter_type = (g_free (adapter_type), NULL), _tmp4);
+				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
 			}
 		} else {
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
-				char* _tmp6;
-				char* _tmp5;
-				GError* _tmp4;
-				GError* _tmp3;
+				char* _tmp8;
+				char* _tmp7;
+				GError* _tmp6;
+				GError* _tmp5;
 				gerror = NULL;
 				debug = NULL;
+				_tmp8 = NULL;
+				_tmp7 = NULL;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
-				debug = (_tmp6 = _tmp5, debug = (g_free (debug), NULL), _tmp6);
-				g_critical ("Device.vala:118: %s %s", gerror->message, debug);
+				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
+				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
+				g_critical ("Device.vala:125: %s %s", gerror->message, debug);
 				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
 			}
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
 	if (_vala_strcmp0 (adapter_type, "DVB-T") == 0) {
-		DVBAdapterType _tmp7;
-		return (_tmp7 = DVB_ADAPTER_TYPE_DVB_T, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp7);
+		DVBAdapterType _tmp9;
+		return (_tmp9 = DVB_ADAPTER_TYPE_DVB_T, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp9);
 	} else {
 		if (_vala_strcmp0 (adapter_type, "DVB-S") == 0) {
-			DVBAdapterType _tmp8;
-			return (_tmp8 = DVB_ADAPTER_TYPE_DVB_S, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp8);
+			DVBAdapterType _tmp10;
+			return (_tmp10 = DVB_ADAPTER_TYPE_DVB_S, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp10);
 		} else {
 			if (_vala_strcmp0 (adapter_type, "DVB-C") == 0) {
-				DVBAdapterType _tmp9;
-				return (_tmp9 = DVB_ADAPTER_TYPE_DVB_C, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp9);
+				DVBAdapterType _tmp11;
+				return (_tmp11 = DVB_ADAPTER_TYPE_DVB_C, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp11);
 			} else {
-				DVBAdapterType _tmp10;
-				return (_tmp10 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp10);
+				DVBAdapterType _tmp12;
+				return (_tmp12 = DVB_ADAPTER_TYPE_UNKNOWN, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp12);
 			}
 		}
 	}
 	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
 	(pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL));
 	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+	adapter_type = (g_free (adapter_type), NULL);
 }
 
 
-static const char* dvb_device_getAdapterName (guint adapter, gboolean get_name) {
+static char* dvb_device_getAdapterName (guint adapter, gboolean get_name) {
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp1;
+	GstElement* _tmp2;
 	GstBus* bus;
-	const char* adapter_name;
-	char* _tmp7;
+	char* adapter_name;
+	char* _tmp9;
 	if (!get_name) {
 		return NULL;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
+	if (dvbsrc == NULL) {
+		char* _tmp1;
+		g_critical ("Device.vala:142: Could not create dvbsrc element");
+		_tmp1 = NULL;
+		return (_tmp1 = NULL, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+	}
 	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
-	_tmp1 = NULL;
-	gst_bin_add ((GST_BIN (pipeline)), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
+	_tmp2 = NULL;
+	gst_bin_add ((GST_BIN (pipeline)), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	adapter_name = NULL;
 	while (gst_bus_have_pending (bus)) {
 		GstMessage* msg;
-		gboolean _tmp2;
+		gboolean _tmp3;
 		msg = gst_bus_pop (bus);
-		_tmp2 = FALSE;
+		_tmp3 = FALSE;
 		if (msg->type == GST_MESSAGE_ELEMENT) {
-			_tmp2 = msg->src == GST_OBJECT (dvbsrc);
+			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
 		} else {
-			_tmp2 = FALSE;
+			_tmp3 = FALSE;
 		}
-		if (_tmp2) {
+		if (_tmp3) {
 			const GstStructure* structure;
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				adapter_name = gst_structure_get_string (structure, "name");
+				char* _tmp4;
+				_tmp4 = NULL;
+				adapter_name = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), adapter_name = (g_free (adapter_name), NULL), _tmp4);
+				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
 			}
 		} else {
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
-				char* _tmp6;
-				char* _tmp5;
-				GError* _tmp4;
-				GError* _tmp3;
+				char* _tmp8;
+				char* _tmp7;
+				GError* _tmp6;
+				GError* _tmp5;
 				gerror = NULL;
 				debug = NULL;
+				_tmp8 = NULL;
+				_tmp7 = NULL;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
-				_tmp4 = NULL;
-				_tmp3 = NULL;
-				(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
-				debug = (_tmp6 = _tmp5, debug = (g_free (debug), NULL), _tmp6);
-				g_critical ("Device.vala:158: %s %s", gerror->message, debug);
+				(gst_message_parse_error (msg, &_tmp5, &_tmp7), gerror = (_tmp6 = _tmp5, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp6));
+				debug = (_tmp8 = _tmp7, debug = (g_free (debug), NULL), _tmp8);
+				g_critical ("Device.vala:169: %s %s", gerror->message, debug);
 				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
 			}
 		}
+		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
-	_tmp7 = NULL;
-	return (_tmp7 = adapter_name, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp7);
+	_tmp9 = NULL;
+	return (_tmp9 = adapter_name, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp9);
 }
 
 
@@ -421,6 +449,7 @@ void dvb_device_set_RecordingsDirectory (DVBDevice* self, GFile* value) {
 
 static void dvb_device_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBDevice * self;
+	gpointer boxed;
 	self = DVB_DEVICE (object);
 	switch (property_id) {
 		case DVB_DEVICE_ADAPTER:
