@@ -29,17 +29,24 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 static gboolean dvb_satellite_channel_real_is_valid (DVBChannel* base) {
 	DVBSatelliteChannel * self;
 	gboolean _tmp0;
+	gboolean _tmp1;
 	self = (DVBSatelliteChannel*) base;
 	_tmp0 = FALSE;
+	_tmp1 = FALSE;
 	if (DVB_CHANNEL_CLASS (dvb_satellite_channel_parent_class)->is_valid (DVB_CHANNEL (self))) {
-		gboolean _tmp1;
+		_tmp1 = self->priv->_SymbolRate != 0;
+	} else {
 		_tmp1 = FALSE;
+	}
+	if (_tmp1) {
+		gboolean _tmp2;
+		_tmp2 = FALSE;
 		if (_vala_strcmp0 (self->priv->_Polarization, "v") == 0) {
-			_tmp1 = TRUE;
+			_tmp2 = TRUE;
 		} else {
-			_tmp1 = _vala_strcmp0 (self->priv->_Polarization, "h") == 0;
+			_tmp2 = _vala_strcmp0 (self->priv->_Polarization, "h") == 0;
 		}
-		_tmp0 = (_tmp1);
+		_tmp0 = (_tmp2);
 	} else {
 		_tmp0 = FALSE;
 	}
@@ -60,8 +67,12 @@ static void dvb_satellite_channel_real_setup_dvb_source (DVBChannel* base, GstEl
 
 static char* dvb_satellite_channel_real_to_string (DVBChannel* base) {
 	DVBSatelliteChannel * self;
+	char* _tmp0;
+	char* _tmp1;
 	self = (DVBSatelliteChannel*) base;
-	return g_strdup_printf ("%s:%u:%s:%d:%u:%u:%u:%u", dvb_channel_get_Name (DVB_CHANNEL (self)), dvb_channel_get_Frequency (DVB_CHANNEL (self)), self->priv->_Polarization, self->priv->_DiseqcSource, self->priv->_SymbolRate, dvb_channel_get_VideoPID (DVB_CHANNEL (self)), dvb_channel_get_AudioPID (DVB_CHANNEL (self)), dvb_channel_get_Sid (DVB_CHANNEL (self)));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s:%u:%s:%d:%u:%u:%s:%u", dvb_channel_get_Name (DVB_CHANNEL (self)), dvb_channel_get_Frequency (DVB_CHANNEL (self)), self->priv->_Polarization, self->priv->_DiseqcSource, self->priv->_SymbolRate, dvb_channel_get_VideoPID (DVB_CHANNEL (self)), _tmp0 = dvb_channel_get_audio_pids_string (DVB_CHANNEL (self)), dvb_channel_get_Sid (DVB_CHANNEL (self))), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
@@ -122,6 +133,7 @@ void dvb_satellite_channel_set_DiseqcSource (DVBSatelliteChannel* self, gint val
 
 static void dvb_satellite_channel_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBSatelliteChannel * self;
+	gpointer boxed;
 	self = DVB_SATELLITE_CHANNEL (object);
 	switch (property_id) {
 		case DVB_SATELLITE_CHANNEL_POLARIZATION:
